@@ -78,9 +78,7 @@
 #  define CHAR_BIT (8)
 #endif
 
-#ifndef FINDERRS_H
-# include "FindErrs.h"
-#endif /* FINDERRS_H */
+#include "FindErrs.h"
 
 #if defined(HAVE_FILENO) && defined(HAVE_ISATTY)
 #  include <stdio.h>
@@ -93,9 +91,6 @@
 #if defined(__unix__) || defined(__unix) || defined(unix)
 #undef __unix__
 #define __unix__ 1
-#elif defined(AMIGA) || defined(__AMIGA) || defined(__amigados__)
-#undef AMIGA
-#define AMIGA 1
 #elif defined(MSDOS) || defined(__MSDOS__) || defined(__msdos__)
 #undef __MSDOS__
 #define __MSDOS__ 1
